@@ -1,6 +1,6 @@
 #!/usr/bin/python3.7
 # -*- coding: utf-8 -*-
-
+import os
 import re
 # 第一个datetime是包，第二个datetime是模块
 import time
@@ -8,11 +8,13 @@ from datetime import datetime, timedelta
 import jieba.posseg as psg
 import query_toolkits.utils as utils
 
-
+_get_module_path = lambda path: os.path.normpath(os.path.join(os.getcwd(),
+                                                 os.path.dirname(__file__), path))
 class Extractor:
     def __init__(self):
-        self.unit_transform = utils._read_table()
-        self.organization = utils._read_list()
+        self.unit_transform = utils._read_table(_get_module_path("unit_transform"))
+        self.organization = utils._read_list(_get_module_path("organization.txt"))
+        self.keyword = utils._read_list(_get_module_path("keyword.txt"))
 
     def _check_time_valid(self, word):
         m = re.match("\d+$", word)
@@ -319,20 +321,28 @@ class Extractor:
         for part in res:
             if part in self.organization:
                 org_name = part
-        # org = utils.max_backward_match(text, self.organization, 40)
-        # if len(org) > 0:
-        #     org = org[0]
-        #     org_name = org[0]
-        #     query = query[org[2]:]
+                break
+        if not org_name:
+            org = utils.max_backward_match(text, self.organization, 40)
+            for elem in org:
+                if len(elem[0]) >= 3:
+                    org_name = elem[0]
+                    query = query[elem[2]:]
+                    break
+        if org_name:
+            org_name = utils.max_backward_match_end(org_name, self.keyword)
 
-        res = re.search('[〔\[\(［]?\s*([0-9]{4})\s*[〕\]\)］]?\s*[年]?\s*[第]?([0-9]+)\s*号', query)
+        res = re.search('[〔\[\(［]?\s*([0-9]{4})\s*[〕\]\)］]?\s*[年]?\s*[第]?\s*([0-9]+)\s*号', query)
         if res:
             year = res.group(1)
             number = res.group(2)
+        else:
+            res = re.search('[第]?\s*([0-9]+)\s*号[文]?', query)
+            if res:
+                number = res.group(1)
         res = re.search('[a-zA-Z]+/[a-zA-Z]+\s*[0-9]+(\.[0-9]+)?[—-][0-9]{4}', query)
         if res:
             another_number = res.group(0)
-
         return org_name, year, number, another_number
 
 
@@ -393,10 +403,14 @@ class Extractor:
 
 
 
-
+"""
 if __name__ == '__main__':
     et = Extractor()
-    res1, res2, res3, res4 = et.extract_reference_no("银发〔2020〕10号/JR/T 0173-2020")
+    cut_res = list(psg.cut("最热的"))
+    print(et.extract_requirement( cut_res))
+    cut_res = list(psg.cut("5g"))
+    print(et.extract_number(cut_res))
+    res1, res2, res3, res4 = et.extract_reference_no("银监三发")
     print(res1, res2, res3, res4)
     print(datetime.today())
     start = time.time()
@@ -452,4 +466,4 @@ if __name__ == '__main__':
         res = et.extract_time(text, cut_res)
         print(res)
     print((time.time() - start)/len(li))
-
+"""
